import fetch from '../../../../config/fetch';
const baseUrl = "/activiti";
const baseUrl2 = "/neikong";
const baseUrl3 = "/leasing";


/**
* @description 查询表单费项
* @method POST
* @param	serialNumber   * 表单流水号
* @param	projectId   *项目ID
*/
export const listFormFeeItem = (data) => fetch('/auditFormFeeItem/listFormFeeItem',baseUrl3,data,'JSON', 'POST','FORMDATA');

/**
 * @description 获取指定人可以审批的审批项列表
 * @method GET
 * @param	approveUserId * 审批任务的代办人ID
 * @param	processKey 流程key(可以通过/activiti/activitiModel/getProcessDefinition接口获取)
 * @param	doneOrNotDone 代办or已办(0:代办;1：已办;)
 * @param	approveState 审批状态(0:审批中;1：通过;2：驳回)
 * @param	timeConditionType 时间筛选（1:本月（默认）;2:最近三个月;3:最近六个月;4:自定义;）
 * @param	tjTimeStart （审批发起时间）统计开始范围（2018-01-02）
 * @param	tjTimeEnd （审批发起时间）统计日期结束范围（2018-02-02）
 * @param	pageIndex *
 * @param	pageSize *
 */
export const getApproveListByAuditUserId = (data) => fetch('/activiti/process/getApproveListByAuditUserId',baseUrl,data,'JSON', 'GET','JSON');
/**
 * @description 获取抄送我的审批项列表
 * @method GET
 * @param	copyUserId  * 抄送人ID
 * @param	processKey 流程key(可以通过/activiti/activitiModel/getProcessDefinition接口获取)
 * @param	doneOrNotDone 代办or已办(0:代办;1：已办;)
 * @param	approveState 审批状态(0:审批中;1：通过;2：驳回)
 * @param	timeConditionType 时间筛选（1:本月（默认）;2:最近三个月;3:最近六个月;4:自定义;）
 * @param	tjTimeStart （审批发起时间）统计开始范围（2018-01-02）
 * @param	tjTimeEnd （审批发起时间）统计日期结束范围（2018-02-02）
 * @param	pageIndex *
 * @param	pageSize *
 */
export const getApproveListByCopyUserId = (data) => fetch('/activiti/process/getApproveListByCopyUserId',baseUrl,data,'JSON', 'GET','JSON');

/**
 * @description 获取指定人发起的审批项列表
 * @method GET
 * @param	launchUserId   * 审批任务的发起人ID
 * @param	processKey 流程key(可以通过/activiti/activitiModel/getProcessDefinition接口获取)
 * @param	doneOrNotDone 代办or已办(0:代办;1：已办;)
 * @param	approveState 审批状态(0:审批中;1：通过;2：驳回)
 * @param	timeConditionType 时间筛选（1:本月（默认）;2:最近三个月;3:最近六个月;4:自定义;）
 * @param	tjTimeStart （审批发起时间）统计开始范围（2018-01-02）
 * @param	tjTimeEnd （审批发起时间）统计日期结束范围（2018-02-02）
 * @param	pageIndex *
 * @param	pageSize *
 */
export const getApproveListByLaunchUserId = (data) => fetch('/activiti/process/getApproveListByLaunchUserId',baseUrl,data,'JSON', 'GET','JSON');

/**
* @description 根据审批项ID获取详情
* @method GET
* @param	approveItemId  * 审批项ID
* @param	currentAuditFlag -1:查询出当前审批级别的审批记录（默认）;0：查询出所有的审批记录;其余的就是查询出指定级别的审批记录
* @param	approveOrCopyUserId 当前审批人或者抄送人 ,可以判断是否可以审核或者是不是抄送人
*/
export const getApproveDetailById = (data) => fetch('/activiti/process/getApproveDetailById',baseUrl,data,'JSON', 'GET','JSON');

/**
* @description 根据审批项ID获取备注详情
* @method GET
* @param	approveItemId  * 审批项ID
* @param	commentUserId 备注人ID
*/
export const getApproveComment = (data) => fetch('/activiti/process/getApproveComment',baseUrl,data,'JSON', 'GET','JSON');

/**
* @description 添加备注
* @method POST
* @param	auditItemId  * 审批项目表ID
* @param	commentUserId  *备注人ID
* @param	commentUserAccount *备注人账号
* @param	commentUserName *备注人名称
* @param	commentUserPhone 备注人电话
* @param	comments *备注内容
* @param	attachment 备注时添加的附件信息 json字符串
*/
export const saveComment = (data) => fetch('/activiti/process/saveComment',baseUrl,data,'JSON', 'POST','FORMDATA');


/**
* @description 删除备注
* @method POST
* @param	commentId *   备注ID
*/
export const deleteComment = (data) => fetch('/activiti/process/deleteComment',baseUrl,data,'JSON', 'POST','FORMDATA');


/**
* @description 审批人进行审批操作
* @method POST
* @param	approveItemId *   审批项ID
* @param	actTaskId *   任务ID
* @param	approveUserId *   审批任务的代办人ID
* @param	apvFlag *   审批结果(1:通过,2:驳回)
* @param	approveContent    审批内容
* @param	operator *   操作人
*/
export const executeApprove = (data) => fetch('/activiti/process/executeApprove',baseUrl,data,'JSON', 'POST','FORMDATA');

/**
* @description 撤销一个流程
* @method POST
* @param	approveItemId *   审批项ID
* @param	approveLaunchUserId  *   申请发起人ID
*/
export const revokeProcess = (data) => fetch('/activiti/process/revokeProcess',baseUrl,data,'JSON', 'POST','FORMDATA');

/**
* @description 上传图片接口 返回唯一的图片名称.字段属性：fileName
* @method POST
* @param	approveItemId *   审批项ID
* @param	approveLaunchUserId  *   申请发起人ID
*/
export const saveFile = (data) => fetch('/saveFile',baseUrl2,data,'JSON', 'POST','FORMDATA');

export const upLoad = (data) => fetch('/rest/uploadFileInfo/uploadMutiFile','/landcrm',data,'JSON', 'POST','FORMDATA');


// 漕河泾 审批详情
// /chjAuditForm/getByProcessKeyAndSerialNum
// 根据流程key和流水号查询
export const getByProcessKeyAndSerialNum = (data) => fetch('/chjAuditForm/getByProcessKeyAndSerialNum','/leasing',data,'JSON', 'GET','JSON');

/**
 * processKey  流程key
 * serialNumber  流水号
 * /auditform/getByProcessKeyAndId
根据流程key和流水号查询
 */
// 金茂的审批详情
export const getByProcessKeyAndId = (data) => fetch('/auditform/getByProcessKeyAndId','/leasing',data,'JSON', 'GET','JSON');


// 退租提交
export const saveActivitiRentWithdraw = (data) => fetch('/auditform/saveActivitiRentWithdraw','/leasing',data,'JSON', 'POST','JSON');


// 获取数量
export const getApproveListByAuditUserIdCount = (data) => fetch('/activiti/process/getApproveListByAuditUserIdCount','/activiti',data,'JSON', 'GET','JSON');

// http://180.168.37.139/activiti/activiti/process/getApproveListByAuditUserIdCount
// serialNumber  合同列表
export const getContractFeeitemSetting = (data) => fetch('/leasingContractFeeitemSetting','/leasing',data,'JSON', 'GET','JSON');

// 附件
// relationType: 1
// fkId: CW2020010037
export const getLeasingFileInfoList = (data) => fetch('/fileInfo/getLeasingFileInfoList','/neikong',data,'JSON', 'GET','JSON');

// 车位合同
export const parklotFeeitemList = (data) => fetch('/leasingContractFeeitemSetting/parklotFeeitemList', '/leasing', data, 'JSON', 'GET', 'JSON');

// 有偿服务合同
export const getDetailBySerialNumber = (data) => fetch('/leasingContractPaidServiceSerialnum/getDetailBySerialNumber', '/leasing', data, 'JSON', 'POST', 'FORMDATA');

//
export const detail = (data) => fetch('/leasingContractParklot/detail', '/leasing', data, 'JSON', 'GET', 'JSON');

//房屋合同
export const getHouseContractInfo = (data) => fetch('/houseContract/getHouseContractInfo', '/leasing', data, 'JSON', 'GET', 'FORMDATA');
