import fetch from './base/fetch2'

/**
 * @description 数据字典  获取列表数据
 * @param {Object} data
 * @author tongyy
 */
export const getBaseData = (data) => fetch('/tsDictDetail/getListByMap', '/walter', data, 'JSON', 'GET', 'JSON')

/**
 * @description 手机端获取业主认证房间分页数据
 * @method POST
 * @param {Object} params e.g. {"ownerId": "6A37FF50-E51D-46E2-941E-9F6E594799F2" }
 * @returns {Promise<*>}
 * @author 林刚正
 */
export const findLocations = (pathArray,params) => fetch('/ownerAuthInfo/findBuildLocation', '/walter', params, 'JSON', 'POST', 'JSON',pathArray)

/**
 * @description 查询物品放行列表
 * @method POST
 * @param {Object} params 
 * {
 *  "size": "string", // 每页数量，必填
 *  "Index": "string", // 页码, 必填
 *  "areaId": "string", // 区域id
 *  "projectId": "string", // 项目ID
 *  "pedestrians": "string", // 放行人
 *  "state": "string", // 放行状态
 *  "startTime": "string", // 预计开始时间
 *  "endTime": "string", // 预计结束时间
 *  "ownerName": "string", // 业主姓名
 *  "releaseNumber": "string", // 物品方向编号
 * }
 * @author 过耀峰
 */
export const queryItemPassportList = (params) => fetch('/decpassManagement/findList', '/itemPassport', params, 'JSON', 'POST', 'JSON')

/**
 * @description 删除物品放行信息
 * @param {Object} params 
 * {
 * "releaseNumber": "string" // 物品放行条ID
 * }
 * @author 过耀峰
 */
export const cancelItemPassportApply = (params) => fetch('/decpassManagement/delDecpass', '/itemPassport', params, 'JSON', 'POST', 'JSON')

/**
 * @description 查询物品放行，放行条二维码
 * @deprecated 已经不用这个接口了, 二维码直接用vux qrcode组件直接生成
 * @param {Array} pathArr 传放行条ID ["string"]
 * @author 过耀峰
 */
export const queryItemPassprotQrcode = (pathArr) => fetch('/exportDecpassMord', '/itemPassport', {}, 'JSON', 'POST', 'JSON', pathArr)

/**
 * @description 修改放行信息
 * @method POST
 * @param {Object} params 
 * {
 * "releaseNumber": "string", // 放行条编号
 * "descriptionContent": "string", // 描述内容
 * "pedestrians": "string", // 放行人
 * "passageTime": "string", // 通行时间
 * "submitter": "string" // 提交人
 * }
 * @author 过耀峰
 */
export const editItemPassport = (params) => fetch('/decpassManagement/updateDecpss', '/itemPassport', params, 'JSON', 'POST', 'JSON')

/**
 * @description 微信上传图片
 * @param {Array} pathArr  传微信userId，e.g. ['a8b1b092-6889-451c-8b1d-40f141fd9920']
 * @returns {Promise<*>}
 * @author  黄智恒
 */
export const uploadFileByWx = (params) => fetch('/wechatInfo/uploadFileByWx', '/walter', params, 'JSON', 'POST', 'JSON')

/**
 * @description 上传pc端图片
 * @method POST
 * @param imgData, imgType, imgSize, count, orderId
 * @author jgj
 */
export const uploadFileByLocal = (data) => fetch('/rest/goodsModuleInfo/uploadFileByLocal', '/crm400',  data, 'XML', 'POST', 'FORMDATA');
